package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.GovernmentExtranetAccess;

/**
 * 政务外网接入Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface IGovernmentExtranetAccessService 
{
    /**
     * 查询政务外网接入
     * 
     * @param id 政务外网接入主键
     * @return 政务外网接入
     */
    public GovernmentExtranetAccess selectGovernmentExtranetAccessById(Integer id);

    /**
     * 查询政务外网接入列表
     * 
     * @param governmentExtranetAccess 政务外网接入
     * @return 政务外网接入集合
     */
    public List<GovernmentExtranetAccess> selectGovernmentExtranetAccessList(GovernmentExtranetAccess governmentExtranetAccess);

    /**
     * 新增政务外网接入
     * 
     * @param governmentExtranetAccess 政务外网接入
     * @return 结果
     */
    public int insertGovernmentExtranetAccess(GovernmentExtranetAccess governmentExtranetAccess);

    /**
     * 修改政务外网接入
     * 
     * @param governmentExtranetAccess 政务外网接入
     * @return 结果
     */
    public int updateGovernmentExtranetAccess(GovernmentExtranetAccess governmentExtranetAccess);

    /**
     * 批量删除政务外网接入
     * 
     * @param ids 需要删除的政务外网接入主键集合
     * @return 结果
     */
    public int deleteGovernmentExtranetAccessByIds(Integer[] ids);

    /**
     * 删除政务外网接入信息
     * 
     * @param id 政务外网接入主键
     * @return 结果
     */
    public int deleteGovernmentExtranetAccessById(Integer id);
}
